@@ -1,8 +1,10 @@
-__version__ = "2.1.1"
+__version__ = "2.3.0"
 
 
 from .case import CaseArtifact as CaseArtifact
-from .case import CaseRunner as CaseRunner
 from .case import derive_from_filename as derive_from_filename
 from .case import trickles as trickles
 from .embrace import Embrace as Embrace
+
+# defining __all__ for the sake of generating docs with pdoc
+__all__ = ["CaseArtifact", "derive_from_filename", "trickles", "Embrace"]
